@@ -303,11 +303,7 @@ package Sidef::Types::Glob::File {
     sub abs_name {
         my $class = ref($_[0]) || shift(@_);
         my ($self, $base) = @_;
-        $class->new(
-                    Encode::decode_utf8(
-                          File::Spec->rel2abs(Encode::encode_utf8("$self"), defined($base) ? Encode::encode_utf8("$base") : ())
-                    )
-                   );
+        $class->new(Encode::decode_utf8(File::Spec->rel2abs(Encode::encode_utf8("$self"), defined($base) ? Encode::encode_utf8("$base") : ())));
     }
 
     *abs     = \&abs_name;
@@ -317,11 +313,7 @@ package Sidef::Types::Glob::File {
     sub rel_name {
         my $class = ref($_[0]) || shift(@_);
         my ($self, $base) = @_;
-        $class->new(
-                    Encode::decode_utf8(
-                          File::Spec->rel2abs(Encode::encode_utf8("$self"), defined($base) ? Encode::encode_utf8("$base") : ())
-                    )
-                   );
+        $class->new(Encode::decode_utf8(File::Spec->rel2abs(Encode::encode_utf8("$self"), defined($base) ? Encode::encode_utf8("$base") : ())));
     }
 
     *rel     = \&rel_name;
@@ -458,6 +450,22 @@ package Sidef::Types::Glob::File {
         $success ? $fh_obj : undef;
     }
 
+    sub symlink {
+        ref($_[0]) || shift(@_);
+        my ($self, $newfile) = @_;
+        CORE::symlink($self, $newfile)
+          ? Sidef::Types::Bool::Bool::TRUE
+          : Sidef::Types::Bool::Bool::FALSE;
+    }
+
+    sub link {
+        ref($_[0]) || shift(@_);
+        my ($self, $newfile) = @_;
+        CORE::link($self, $newfile)
+          ? Sidef::Types::Bool::Bool::TRUE
+          : Sidef::Types::Bool::Bool::FALSE;
+    }
+
     sub touch {
         ref($_[0]) || shift(@_);
         my ($self, @args) = @_;
