@@ -225,18 +225,39 @@ package Sidef::Types::String::String {
         bless \(my $t = CORE::substr($$self, 0, defined($num) ? CORE::int($num) : 1));
     }
 
+    *head = \&first;
+
     sub last {
         my ($self, $num) = @_;
         bless \(my $t = CORE::substr($$self, defined($num) ? -(CORE::int($num) || return $self->new('')) : -1));
     }
 
+    *tail = \&last;
+
     sub char {
         my ($self, $pos) = @_;
-        bless \(my $t = CORE::substr($$self, CORE::int($pos), 1));
+        bless \(my $t = CORE::substr($$self, CORE::int($pos), 1) // '');
     }
 
     *char_at = \&char;
 
+    sub byte {
+        my ($self, $pos) = @_;
+
+        require bytes;
+
+        $pos = CORE::int($pos);
+
+        if ($pos >= bytes::length($$self)) {
+            return undef;
+        }
+
+        my $char = bytes::substr($$self, $pos, 1) // return undef;
+        Sidef::Types::Number::Number::_set_int(CORE::ord($char));
+    }
+
+    *byte_at = \&byte;
+
     sub wordcase {
         my ($self) = @_;
 
@@ -339,36 +360,36 @@ package Sidef::Types::String::String {
 
     sub decode_base64 {
         state $x = require MIME::Base64;
-        bless \MIME::Base64::decode_base64(${$_[0]});
+        bless \(my $value = MIME::Base64::decode_base64(${$_[0]}));
     }
 
     *base64_decode = \&decode_base64;
 
     sub encode_base64 {
         state $x = require MIME::Base64;
-        bless \MIME::Base64::encode_base64(${$_[0]});
+        bless \(my $value = MIME::Base64::encode_base64(${$_[0]}));
     }
 
     *base64_encode = \&encode_base64;
 
     sub md5 {
         state $x = require Digest::MD5;
-        bless \Digest::MD5::md5_hex(${$_[0]});
+        bless \(my $value = Digest::MD5::md5_hex(${$_[0]}));
     }
 
     sub sha1 {
         state $x = require Digest::SHA;
-        bless \Digest::SHA::sha1_hex(${$_[0]});
+        bless \(my $value = Digest::SHA::sha1_hex(${$_[0]}));
     }
 
     sub sha256 {
         state $x = require Digest::SHA;
-        bless \Digest::SHA::sha256_hex(${$_[0]});
+        bless \(my $value = Digest::SHA::sha256_hex(${$_[0]}));
     }
 
     sub sha512 {
         state $x = require Digest::SHA;
-        bless \Digest::SHA::sha512_hex(${$_[0]});
+        bless \(my $value = Digest::SHA::sha512_hex(${$_[0]}));
     }
 
     sub parse_quotewords {
@@ -437,7 +458,7 @@ package Sidef::Types::String::String {
 
     sub join {
         my ($self, @rest) = @_;
-        bless \CORE::join($$self, @rest);
+        bless \(my $value = CORE::join($$self, @rest));
     }
 
     sub clear {
@@ -603,6 +624,8 @@ package Sidef::Types::String::String {
           : Sidef::Types::Bool::Bool::FALSE;
     }
 
+    *sayf = \&printlnf;
+
     sub sprintf {
         my ($self, @arguments) = @_;
         $self->new(CORE::sprintf $$self, @arguments);
@@ -684,7 +707,7 @@ package Sidef::Types::String::String {
     sub glob {
         my ($self) = @_;
         state $x = require Encode;
-        Sidef::Types::Array::Array->new([map { bless \Encode::decode_utf8($_) } CORE::glob($$self)]);
+        Sidef::Types::Array::Array->new([map { bless \(my $value = Encode::decode_utf8($_)) } CORE::glob($$self)]);
     }
 
     sub quotemeta {
@@ -734,6 +757,30 @@ package Sidef::Types::String::String {
         $self;
     }
 
+    sub cons {
+        my ($self, $n) = @_;
+        $n = CORE::int($n);
+        $n > 0 or return Sidef::Types::Array::Array->new;
+        my @strings;
+        foreach my $i (0 .. CORE::length($$self) - $n) {
+            push @strings, bless \(my $str = CORE::substr($$self, $i, $n));
+        }
+        Sidef::Types::Array::Array->new(\@strings);
+    }
+
+    sub each_cons {
+        my ($self, $n, $block) = @_;
+
+        $n = CORE::int($n);
+        $n > 0 or return $self;
+
+        foreach my $i (0 .. CORE::length($$self) - $n) {
+            $block->run(bless \(my $str = CORE::substr($$self, $i, $n)));
+        }
+
+        $self;
+    }
+
     sub split {
         my ($self, $sep, $size) = @_;
 
@@ -1168,7 +1215,7 @@ package Sidef::Types::String::String {
     *lev   = \&levenshtein;
     *leven = \&levenshtein;
 
-    sub jaro_distance {
+    sub jaro {
         my ($s, $t, $winkler) = @_;
 
         $s = $$s;
@@ -1221,7 +1268,7 @@ package Sidef::Types::String::String {
 
         my $jaro = (($matches / $s_len) + ($matches / $t_len) + (($matches - $transpositions / 2) / $matches)) / 3;
 
-        $winkler || return Sidef::Types::Number::Number->new($jaro);    # return the Jaro distance instead of Jaro-Winkler
+        $winkler || return Sidef::Types::Number::Number->new($jaro);    # return the Jaro similarity instead of Jaro-Winkler
 
         my $prefix = 0;
         foreach my $i (0 .. List::Util::min(3, $#t, $#s)) {
@@ -1727,7 +1774,7 @@ package Sidef::Types::String::String {
             my $str = "${$_[0]}";
 
             $str =~ s/([\\\"]|#\{)/\\$1/g;
-            $str =~ /[^\040-\176]/ or return bless \qq("$str");
+            $str =~ /[^\040-\176]/ or return bless \(my $value = qq("$str"));
 
             $str =~ s/([\a\b\t\n\f\r\e\13])/$esc{$1}/g;
             $str =~ s/([\0-\037])(?!\d)/CORE::sprintf('\\%o',CORE::ord($1))/eg;
@@ -1735,7 +1782,7 @@ package Sidef::Types::String::String {
             $str =~ s/([\0-\037\177-\377])/CORE::sprintf('\\x%02X',CORE::ord($1))/eg;
             $str =~ s/([^\040-\176])/CORE::sprintf('\\x{%X}',CORE::ord($1))/eg;
 
-            bless \qq("$str");
+            bless \(my $value2 = qq("$str"));
         }
     }
 
